==> pcsx2-2.4.0.tar.gz: pcsx2-2.4.0/pcsx2-qt/Translations/pcsx2-qt_en-US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US" sourcelanguage="en_US">
<context>
    <name>AchievementSettingsWidget</name>
    <message numerus="yes">
        <location filename="../Settings/AchievementSettingsWidget.cpp" line="134"/>
        <location filename="../Settings/AchievementSettingsWidget.cpp" line="141"/>
        <source>%n seconds</source>
        <translation>
            <numerusform>%n second</numerusform>
            <numerusform>%n seconds</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Achievements</name>
    <message numerus="yes">
        <location filename="../../pcsx2/Achievements.cpp" line="1023"/>
        <source>You have unlocked {} of %n achievements</source>
        <comment>Achievement popup</comment>
        <translation>
            <numerusform>You have unlocked {} of %n achievements</numerusform>
            <numerusform>You have unlocked {} of %n achievements</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../pcsx2/Achievements.cpp" line="1026"/>
        <source>and earned {} of %n points</source>
        <comment>Achievement popup</comment>
        <translation>
            <numerusform>and earned {} of %n points</numerusform>
            <numerusform>and earned {} of %n points</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../pcsx2/Achievements.cpp" line="1111"/>
        <source>%n achievements</source>
        <comment>Mastery popup</comment>
        <translation>
            <numerusform>%n achievement</numerusform>
            <numerusform>%n achievements</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../pcsx2/Achievements.cpp" line="1113"/>
        <source>%n points</source>
        <comment>Mastery popup</comment>
        <translation>
            <numerusform>%n point</numerusform>
            <numerusform>%n points</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameList</name>
    <message numerus="yes">
        <location filename="../GameList/GameListModel.cpp" line="268"/>
        <location filename="../../pcsx2/GameList.cpp" line="1142"/>
        <source>%n hours</source>
        <translation>
            <numerusform>%n hour</numerusform>
            <numerusform>%n hours</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../GameList/GameListModel.cpp" line="270"/>
        <location filename="../../pcsx2/GameList.cpp" line="1144"/>
        <source>%n minutes</source>
        <translation>
            <numerusform>%n minute</numerusform>
            <numerusform>%n minutes</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>InputBindingWidget</name>
    <message numerus="yes">
        <location filename="../Settings/InputBindingWidget.cpp" line="73"/>
        <source>%n bindings</source>
        <translation>
            <numerusform>%n binding</numerusform>
            <numerusform>%n bindings</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Patch</name>
    <message numerus="yes">
        <location filename="../../pcsx2/Patch.cpp" line="698"/>
        <source>%n GameDB patches are active.</source>
        <comment>OSD Message</comment>
        <translation>
            <numerusform>%n GameDB patch is active.</numerusform>
            <numerusform>%n GameDB patches are active.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../pcsx2/Patch.cpp" line="705"/>
        <source>%n game patches are active.</source>
        <comment>OSD Message</comment>
        <translation>
            <numerusform>%n game patch is active.</numerusform>
            <numerusform>%n game patches are active.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../pcsx2/Patch.cpp" line="712"/>
        <source>%n cheat patches are active.</source>
        <comment>OSD Message</comment>
        <translation>
            <numerusform>%n cheat patch is active.</numerusform>
            <numerusform>%n cheat patches are active.</numerusform>
        </translation>
    </message>
</context>
</TS>

==> pcsx2-2.6.0.tar.gz: pcsx2-2.6.0/pcsx2-qt/Translations/pcsx2-qt_en-US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US" sourcelanguage="en_US">
<context>
    <name>AchievementSettingsWidget</name>
    <message numerus="yes">
        <location filename="../Settings/AchievementSettingsWidget.cpp" line="196"/>
        <location filename="../Settings/AchievementSettingsWidget.cpp" line="203"/>
        <source>%n seconds</source>
        <translation>
            <numerusform>%n second</numerusform>
            <numerusform>%n seconds</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Achievements</name>
    <message numerus="yes">
        <location filename="../../pcsx2/Achievements.cpp" line="1104"/>
        <source>You have unlocked {} of %n achievements</source>
        <comment>Achievement popup</comment>
        <translation>
            <numerusform>You have unlocked {} of %n achievements</numerusform>
            <numerusform>You have unlocked {} of %n achievements</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../pcsx2/Achievements.cpp" line="1107"/>
        <source>and earned {} of %n points</source>
        <comment>Achievement popup</comment>
        <translation>
            <numerusform>and earned {} of %n points</numerusform>
            <numerusform>and earned {} of %n points</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../pcsx2/Achievements.cpp" line="1191"/>
        <source>%n achievements</source>
        <comment>Mastery popup</comment>
        <translation>
            <numerusform>%n achievement</numerusform>
            <numerusform>%n achievements</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../pcsx2/Achievements.cpp" line="1193"/>
        <source>%n points</source>
        <comment>Mastery popup</comment>
        <translation>
            <numerusform>%n point</numerusform>
            <numerusform>%n points</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameList</name>
    <message numerus="yes">
        <location filename="../GameList/GameListModel.cpp" line="223"/>
        <location filename="../../pcsx2/GameList.cpp" line="1248"/>
        <source>%n hours</source>
        <translation>
            <numerusform>%n hour</numerusform>
            <numerusform>%n hours</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../GameList/GameListModel.cpp" line="227"/>
        <location filename="../../pcsx2/GameList.cpp" line="1250"/>
        <source>%n minutes</source>
        <translation>
            <numerusform>%n minute</numerusform>
            <numerusform>%n minutes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../pcsx2/GameList.cpp" line="1252"/>
        <source>%n seconds</source>
        <translation>
            <numerusform>%n second</numerusform>
            <numerusform>%n seconds</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>InputBindingWidget</name>
    <message numerus="yes">
        <location filename="../Settings/InputBindingWidget.cpp" line="77"/>
        <source>%n bindings</source>
        <translation>
            <numerusform>%n binding</numerusform>
            <numerusform>%n bindings</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message numerus="yes">
        <location filename="../MainWindow.cpp" line="3061"/>
        <source>%n save states deleted.</source>
        <translation>
            <numerusform>%n save state deleted.</numerusform>
            <numerusform>%n save states deleted.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Patch</name>
    <message numerus="yes">
        <location filename="../../pcsx2/Patch.cpp" line="768"/>
        <source>%n GameDB patches are active.</source>
        <comment>OSD Message</comment>
        <translation>
            <numerusform>%n GameDB patch is active.</numerusform>
            <numerusform>%n GameDB patches are active.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../pcsx2/Patch.cpp" line="775"/>
        <source>%n game patches are active.</source>
        <comment>OSD Message</comment>
        <translation>
            <numerusform>%n game patch is active.</numerusform>
            <numerusform>%n game patches are active.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../pcsx2/Patch.cpp" line="781"/>
        <source>%n cheat patches are active.</source>
        <comment>OSD Message</comment>
        <translation>
            <numerusform>%n cheat patch is active.</numerusform>
            <numerusform>%n cheat patches are active.</numerusform>
        </translation>
    </message>
</context>
</TS>
